#Installation
```python
pip install i2a_chat_api_client
```

#Usage

```python
from i2a_chat_api_client import client

client = client.I2AChatApiClient(x_application_secret='your application secret')
```